@@ -4,6 +4,7 @@ from configurations import Configuration, values
 
 
 class BaseConfig(Configuration):
+    BASE_DIR = Path(__file__).resolve(strict=True).parent.parent
     DEBUG = values.BooleanValue(False)
     ALLOWED_HOSTS = values.ListValue()
     SECRET_KEY = values.SecretValue()
@@ -236,7 +237,7 @@ class BaseConfig(Configuration):
     CRISPY_ALLOWED_TEMPLATE_PACKS = 'tailwind'
     CRISPY_TEMPLATE_PACK = 'tailwind'
 
-    EMAIL_BACKEND = 'ses_sns.backend.FilteringEmailBackend'
+    EMAIL_BACKEND = 'post_office.EmailBackend'
 
     POST_OFFICE = {
         'BACKENDS': {
